# Fixationspunkt

Das `fixation_dot` Plug-in ist ein Bequemlichkeitsplug-in. Das heißt, es kann nichts tun, was mit einem `sketchpad` gemacht werden könnte, aber wenn Sie lediglich ein Fixationspunkt präsentieren wollen, ist es bequemer. 

Folgende Optionen sind verfügbar:

- `Style` definiert den Stil des Fixationspunkts.
- `Duration` sollte eine positive Ganze Zahl,'keypress', or 'mouseclick' sein, um entweder den entsprechenden Intervall in Millisekunden, bis eine Taste gepresst, oder eine Maustaste geklickt wurde. 
- `Foreground color` sollte der englische Name einer Farbe (z.B. 'blue') oder ein HTML Farbenwert (z.B. '#0000FF') sein. 
- `Background color` sollte der englische Name einer Farbe (z.B. 'blue') oder ein HTML Farbenwert (z.B. '#0000FF') sein.
- Die `X` und `Y` Koordinaten spiegeln die Position des Fixationspunkt wieder.
